package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`%0`!````7"4```````!``````````%`!`0``
M`````@```$``.``(`$``%@`5``8````$````0`````````!``````````$``
M````````P`$```````#``0````````@``````````P````0``````@``````
M```"``````````(````````>`````````!X``````````0`````````!````
M!0```````````````````````````````````+RA````````O*$`````````
M``$```````$````&````0/L```````!`^P$``````$#[`0``````.`4`````
M``"8%0```````````0```````@````8```!@^P```````&#[`0``````8/L!
M``````#``0```````,`!````````"`````````!0Y71D!````$2<````````
M1)P```````!$G````````-P`````````W``````````$`````````%'E=&0&
M`````````````````````````````````````````````````````````!``
M````````4N5T9`0```!`^P```````$#[`0``````0/L!``````#`!```````
M`,`$`````````0`````````O;&EB+VQD+6UU<VPM<&]W97)P8S8T;&4N<V\N
M,0```!$```!A````!`````@````@$!``!4`$@"@`$`2`A@"$@B$```D`!`F(
M@!A!N@0""`````!A````90```&D```!J````<````'$```!R`````````'0`
M``!U`````````'8```!W````>0``````````````:G^:?.K3[P[.WD<M;\7?
M'R[%F[:XC?$.U&34?"'_Y`[9<5@<^J%L8,+E/RRR`8MO0OK7A^)'Q@&[XY)\
M5<,\TF>OS&:(!W#30T75[#-BV^T5C"7,?ZF<F^"G`@IK&IY0H^#[20``````
M```````````````````````````````#``<`<!L`````````````````````
M```#``T`0/L!`````````````````"4#```"``@`0%L`````````````````
M`#(#```"``@`/%L``````````````````#\#```"``@`.%L`````````````
M`````$P#```"``@`-%L``````````````````%D#```"``@`+%L`````````
M`````````&8#```"``@`H%L``````````````````',#```"``@`I%L`````
M`````````````(`#```"``@`,%L``````````````````+0#```"``@`4%L`
M`````````````````,$#```"``@`3%L``````````````````,X#```"``@`
M1%L``````````````````-L#```"``@`2%L```````````````````\$```"
M``@`5%L``````````````````!P$```"``@`6%L``````````````````"D$
M```"``@`B%L``````````````````#8$```"``@`;%L`````````````````
M`$,$```"``@`:%L``````````````````%`$```"``@`=%L`````````````
M`````%T$```"``@`<%L``````````````````&H$```"``@`9%L`````````
M`````````*8$```"``@`>%L``````````````````+T$```"``@`?%L`````
M`````````````,H$```"``@`@%L``````````````````-<$```"``@`A%L`
M``````````````````$````28`````````````````````````D````1````
M`````````````````````+H!```1`````````````````````````%8!```2
M8````````````````````````!`````28````````````````````````),!
M```28````````````````````````!@````28```````````````````````
M`,<!```28````````````````````````)\!```28```````````````````
M`````!\````@`````````````````````````-8"```A````````````````
M`````````#<````28````````````````````````#T````2````````````
M`````````````$0````2`````````````````````````*,"```28```````
M`````````````````)0"```28````````````````````````$L````2````
M`````````````````````.T!```28````````````````````````%(````2
M8````````````````````````',"```28````````````````````````%D`
M```28````````````````````````&$````2````````````````````````
M`%P"```28````````````````````````&D````28```````````````````
M`````&\````28````````````````````````'@````@````````````````
M`````````(T"```28````````````````````````)0````28```````````
M`````````````)D````28````````````````````````-@!```1````````
M`````````````````'H"```28````````````````````````!H"```28```
M`````````````````````*`````28`````````````````````````P"```2
M8````````````````````````!P#```28````````````````````````-4"
M```1`````````````````````````#X"```28```````````````````````
M`,("```28````````````````````````-<"```1````````````````````
M`````*<````28````````````````````````+H"```28```````````````
M`````````&0!```28````````````````````````+`````B````````````
M`````````````+\````@`````````````````````````-4````28```````
M`````````````````(4"```28````````````````````````"H"```28```
M`````````````````````-H````28````````````````````````.`````@
M`````````````````````````&<"```28````````````````````````/H`
M```28````````````````````````(0!```28```````````````````````
M`/\````28````````````````````````$P"```28```````````````````
M`````',!```28`````````````````````````4!```2````````````````
M`````````!8!```28````````````````````````.@!```28```````````
M`````````````&H````28````````````````````````/D!```28```````
M`````````````````#,"```28````````````````````````+,"```28```
M`````````````````````!P!```2`````````````````````````*L"```2
M8````````````````````````#`!```2`````````````````````````.,!
M```28````````````````````````#<!```2````````````````````````
M`#X!```2`````````````````````````-0"```A````````````````````
M`````$\!```2`````````````````````````,\"```28`@``",```````!<
M`@```````+0!```28`D`W%P````````0`````````/H#```28`@`)#<`````
M``!`!P```````$(%```28`@`%$$```````"8`````````*,#```28`@`_"\`
M```````8```````````%```28`<`<!L````````0`````````(4$```28`@`
M9#X```````"P`@```````"8%```28`@`%#`````````0`@```````/$$```0
M`!,`>``"`````````````````.@#```28`@`8#8```````#$``````````<$
M```28`@`1"X```````!D`````````'<$```28`@`A#4```````"0````````
M`)L$```28`@`S%<````````T`0```````.0$```2``@`)#(````````T````
M`````#T%```0`!,`V!`"``````````````````$#```28`@`B"4```````!<
M``````````8%```28`@`6#(```````!D`0```````+,$```1`!(`<``"````
M```(`````````!\%```0`!(`>``"`````````````````/8$```2``@`7"4`
M`````````````````/T$```28`@`.%<```````"4``````````H#```28`@`
M%#8```````!,`````````(T#```28`@`("\```````#<`````````#,%```2
M8`@``%D```````"D`0```````!(%```28`@`O#,```````#(`0````````!O
M<&5N9&ER`'-T9&5R<@!R96%L;&]C`&%C8V5S<P!?7V1E<F5G:7-T97)?9G)A
M;65?:6YF;P!L<V5E:P!G971P:60`<W1R8VUP`&UE;7-E=`!U;FQI;FL`;65M
M;6]V90!S=')N8VUP`&QS=&%T`&-L;W-E9&ER`%])5$U?9&5R96=I<W1E<E1-
M0VQO;F5486)L90!O<&5N`'-T<G-T<@!S=')C:'(`<F5A9&QI;FL`7U]C>&%?
M9FEN86QI>F4`7U]R96=I<W1E<E]F<F%M95]I;F9O`&5X:70`8VQO<V4`7TE4
M35]R96=I<W1E<E1-0VQO;F5486)L90!R96%D`')M9&ER`%]?97)R;F]?;&]C
M871I;VX`;6MD:7(`<'1H<F5A9%]G971S<&5C:69I8P!M96UC<'D`<W1R;&5N
M`%]?<W1A8VM?8VAK7V9A:6P`9V5T=6ED`%!E<FQ?<WES7W1E<FT`4&5R;%]S
M>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L
M7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!?9FEN:0!03%]D;U]U;F1U
M;7``4&5R;%]N97=84U]F;&%G<P!03%]T:')?:V5Y`'!E<FQ?9G)E90!097)L
M7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L
M7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T
M`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO
M8P!P97)L7V%L;&]C`&9P<FEN=&8`<W1R9'5P`'!T:')E861?871F;W)K`')E
M861D:7(`<W!R:6YT9@!S=')T;VL`<W1R;F-P>0!?7VQI8F-?<W1A<G1?;6%I
M;@!?7U]E;G9I<F]N`&QI8G!E<FPN<V\`;&EB8RYM=7-L+7!P8S8T;&4N<V\N
M,0!?<W1A<G1?8P!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!?<V%V96=P
M<C!?,C4`7W-A=F5G<'(P7S(T`%]S879E9W!R,%\R,P!?<V%V96=P<C!?,C(`
M7W-A=F5G<'(P7S(P`%]R97-T9W!R,%\S,`!?<F5S=&=P<C!?,S$`7W-A=F5G
M<'(P7S(Q`'!A<E]C=7)R96YT7V5X96-?<')O8P!P87)?8W5R<F5N=%]E>&5C
M`%]S879E9W!R,%\R.0!?<V%V96=P<C!?,C@`7W-A=F5G<'(P7S(V`%]S879E
M9W!R,%\R-P!P87)?<V5T=7!?;&EB<&%T:`!P87)?;6MT;7!D:7(`>'-?:6YI
M=`!?<V%V96=P<C!?,S``7W-A=F5G<'(P7S,Q`%]R97-T9W!R,%\R.0!?<F5S
M=&=P<C!?,C(`7W)E<W1G<'(P7S(Q`%]R97-T9W!R,%\R-`!?<F5S=&=P<C!?
M,C,`7W)E<W1G<'(P7S(P`'!A<E]E;G9?8VQE86X`6%-?26YT97)N86QS7U!!
M4E]"3T]4`'-H85]U<&1A=&4`7W)E<W1G<'(P7S(U`&UY7W!A<E]P;`!?<F5S
M=&=P<C!?,C8`7W)E<W1G<'(P7S(W`%]R97-T9W!R,%\R.`!P87)?8F%S96YA
M;64`7U]B<W-?<W1A<G0`<VAA7VEN:70`<&%R7V1I<FYA;64`<&%R7VEN:71?
M96YV`%]E9&%T80!P87)?9FEN9'!R;V<`<VAA7V9I;F%L`%]E;F0`<&%R7V-L
M96%N=7``+W5S<B]L:6(O<&5R;#4O8V]R95]P97)L+T-/4D4``````````@``
M````%@````````````(``````!```@``````%@````````"Y7P```````!@`
M`@``````%@`````````)70```````"@``@``````%@````````#J70``````
M`#```@``````%@````````#C70```````#@``@``````%@````````"M7P``
M`````$```@``````%@``````````7@```````$@``@``````%@````````"U
M7P```````%@``@``````%@````````"?7P```````&```@``````%@``````
M``"D7P```````'```@``````%@````````"^7P````````C_`0``````)@``
M`#0``````````````!#_`0``````)@```$L``````````````!C_`0``````
M)@```$4``````````````"#_`0``````)@```"0``````````````"C_`0``
M````)@```$8``````````````##_`0``````)@```$$``````````````#C_
M`0``````)@```#@``````````````$#_`0``````)@```%``````````````
M`$C_`0``````)@```!P``````````````%#_`0``````)@```%8`````````
M`````%C_`0``````)@```%$``````````````&#_`0``````)@```!T`````
M`````````##]`0``````%0```!L``````````````#C]`0``````%0```!X`
M`````````````$#]`0``````%0```!\``````````````$C]`0``````%0``
M`"```````````````%#]`0``````%0```"$``````````````%C]`0``````
M%0```"(``````````````&#]`0``````%0```",``````````````&C]`0``
M````%0```"0``````````````'#]`0``````%0```"8``````````````'C]
M`0``````%0```"<``````````````(#]`0``````%0```"@`````````````
M`(C]`0``````%0```"D``````````````)#]`0``````%0```"H`````````
M`````)C]`0``````%0```"L``````````````*#]`0``````%0```"P`````
M`````````*C]`0``````%0```"T``````````````+#]`0``````%0```"X`
M`````````````+C]`0``````%0```"\``````````````,#]`0``````%0``
M`#```````````````,C]`0``````%0```#$``````````````-#]`0``````
M%0```#(``````````````-C]`0``````%0```#,``````````````.#]`0``
M````%0```#4``````````````.C]`0``````%0```#8``````````````/#]
M`0``````%0```#<``````````````/C]`0``````%0```#D`````````````
M``#^`0``````%0```#H```````````````C^`0``````%0```#L`````````
M`````!#^`0``````%0```#P``````````````!C^`0``````%0```#T`````
M`````````"#^`0``````%0```#\``````````````"C^`0``````%0```$``
M`````````````##^`0``````%0```$(``````````````#C^`0``````%0``
M`$,``````````````$#^`0``````%0```$0``````````````$C^`0``````
M%0```$4``````````````%#^`0``````%0```$8``````````````%C^`0``
M````%0```$<``````````````&#^`0``````%0```$@``````````````&C^
M`0``````%0```$D``````````````'#^`0``````%0```$H`````````````
M`'C^`0``````%0```$P``````````````(#^`0``````%0```$T`````````
M`````(C^`0``````%0```$X``````````````)#^`0``````%0```$\`````
M`````````)C^`0``````%0```%(``````````````*#^`0``````%0```%,`
M`````````````*C^`0``````%0```%0``````````````+#^`0``````%0``
M`%4``````````````+C^`0``````%0```%<``````````````,#^`0``````
M%0```%@``````````````,C^`0``````%0```%D``````````````-#^`0``
M````%0```%H``````````````-C^`0``````%0```%L``````````````.#^
M`0``````%0```%P``````````````.C^`0``````%0```%T`````````````
M`/#^`0``````%0```%X``````````````/C^`0``````%0```&``````````
M``````(`3#R08T(XI@((?!```?CA_R'X50P`2````&`]/P!(````8"``(3@0
M``'HI@,(?"``@$X`````````````````````````````````````&`!!^/__
M@CWP?XSII@.)?2`$@$X````````````````8`$'X__^"/<A_C.FF`XE](`2`
M3@```````````````!@`0?C__X(]J'^,Z:8#B7T@!(!.````````````````
M&`!!^/__@CU@?HSII@.)?2`$@$X````````````````8`$'X__^"/?A_C.FF
M`XE](`2`3@```````````````!@`0?C__X(]4'^,Z:8#B7T@!(!.````````
M````````&`!!^/__@CTH?XSII@.)?2`$@$X````````````````8`$'X__^"
M/=A^C.FF`XE](`2`3@```````````````!@`0?C__X(]Z'Z,Z:8#B7T@!(!.
M````````````````&`!!^/__@CTP?XSII@.)?2`$@$X````````````````8
M`$'X__^"/=!^C.FF`XE](`2`3@```````````````!@`0?C__X(]P'Z,Z:8#
MB7T@!(!.````````````````&`!!^/__@CW@?HSII@.)?2`$@$X`````````
M```````8`$'X__^"/1!_C.FF`XE](`2`3@```````````````!@`0?C__X(]
M:'^,Z:8#B7T@!(!.````````````````&`!!^/__@CWP?HSII@.)?2`$@$X`
M```````````````8`$'X__^"/7!_C.FF`XE](`2`3@```````````````!@`
M0?C__X(]:'Z,Z:8#B7T@!(!.````````````````&`!!^/__@CV`?XSII@.)
M?2`$@$X````````````````8`$'X__^"/:A^C.FF`XE](`2`3@``````````
M`````!@`0?C__X(]0'^,Z:8#B7T@!(!.````````````````&`!!^/__@CT@
M?XSII@.)?2`$@$X````````````````8`$'X__^"/?A^C.FF`XE](`2`3@``
M`````````````!@`0?C__X(]B'Z,Z:8#B7T@!(!.````````````````&`!!
M^/__@CT(?XSII@.)?2`$@$X````````````````8`$'X__^"/9!_C.FF`XE]
M(`2`3@```````````````!@`0?C__X(]6'^,Z:8#B7T@!(!.````````````
M````&`!!^/__@CUX?XSII@.)?2`$@$X````````````````8`$'X__^"/4A_
MC.FF`XE](`2`3@```````````````!@`0?C__X(]D'Z,Z:8#B7T@!(!.````
M````````````&`!!^/__@CTX?XSII@.)?2`$@$X````````````````8`$'X
M__^"/3A^C.FF`XE](`2`3@```````````````!@`0?C__X(]L'^,Z:8#B7T@
M!(!.````````````````&`!!^/__@CV@?XSII@.)?2`$@$X`````````````
M```8`$'X__^"/<!_C.FF`XE](`2`3@```````````````!@`0?C__X(]F'^,
MZ:8#B7T@!(!.````````````````&`!!^/__@CU`?HSII@.)?2`$@$X`````
M```````````8`$'X__^"/;A_C.FF`XE](`2`3@```````````````!@`0?C_
M_X(]<'Z,Z:8#B7T@!(!.````````````````&`!!^/__@CW(?HSII@.)?2`$
M@$X````````````````8`$'X__^"/;A^C.FF`XE](`2`3@``````````````
M`!@`0?C__X(]B'^,Z:8#B7T@!(!.````````````````&`!!^/__@CU0?HSI
MI@.)?2`$@$X````````````````8`$'X__^"/3!^C.FF`XE](`2`3@``````
M`````````!@`0?C__X(]H'Z,Z:8#B7T@!(!.````````````````&`!!^/__
M@CW0?XSII@.)?2`$@$X````````````````8`$'X__^"/6!_C.FF`XE](`2`
M3@```````````````!@`0?C__X(]X'^,Z:8#B7T@!(!.````````````````
M&`!!^/__@CV`?HSII@.)?2`$@$X````````````````8`$'X__^"/7A^C.FF
M`XE](`2`3@```````````````!@`0?C__X(]F'Z,Z:8#B7T@!(!.````````
M````````&`!!^/__@CW8?XSII@.)?2`$@$X````````````````8`$'X__^"
M/;!^C.FF`XE](`2`3@```````````````!@`0?C__X(]Z'^,Z:8#B7T@!(!.
M````````````````&`!!^/__@CU(?HSII@.)?2`$@$X````````````````8
M`$'X__^"/0!_C.FF`XE](`2`3@```````````````!@`0?C__X(]6'Z,Z:8#
MB7T@!(!.````````````````&`!!^/__@CT8?XSII@.)?2`$@$X`````````
M```````"`$P\`%Q".*8""'SP_\'[^/_A^Q```?AQ_R'X<`"!^&@`H?AP`($X
M:`"A.'P`89!\`&$X#?O_2Q@`0>@```!@4("BZ````&!8@&+H>"ND?!'\_TL8
M`$'H````8&"`(ND```!@.(#BZP``R8L``!XL0`""0`W[_TL8`$'H````8```
M(RS0D6+X$`""0`$`8#AQ^_]+&`!!Z$G]_TL8`$'H``!_@#WX_TL8`$'HIPO#
MFP``?X`M^/]+&`!!Z/H%(XD"`"EA^@4CF0``?X`5^/]+&`!!Z/H%(XD!`"EA
M^@4CF7P`88`#`.,[!`!C.+0'8WPD'V-X+?O_2Q@`0>AP`.'H````8'P`08$`
M```YP)%B^'@;9GP``"?I```*+```(_G^_R(]F>`I.0@`(_D```!@<($BZ1``
M(_G^_R(]G.`I.1@`(_G__RHY(``I>0$`*3D(`(%!`0`@.0$`*2P$`$@YM`=*
M?0$`"#DD'TIY__\I.112IGS,`()````@.0```&#0D6+H_O^"/```X#BHKX0X
M```E^;0'Y7\)_/]+&`!!Z````RQX&W]\&`""0````&#0D6+HS?C_2Q@`0>AX
M&W]\````8-"18NB9^?]+&`!!Z/[_8CR=WF,X)00`2```(RP\`()`````8,B1
M(ND``"DL&`""0/[_8CQ2WF,X`00`2````&#(D6+X````8,B18N@``",L"`""
M004<`$@```!@T)%BZ'W\_TL8`$'H=?K_2Q@`0>B0`"$XM`?C?V0V`$@D'P5Y
M*BBG?"I1IGP,__]+``````````&``@```@!,/*190C@H`(R`%&*$?'@+(WSD
M!B%X````..'_`?BF`PA\$0``2`36`0`"`$P\>%E".*8""'P(`*,X_O_B/-S=
MYSC^_\(\<)S&.`(`@^C^_V(\`*1C.````#D0``'XX?\A^,'V_TL8`$'H(``A
M.!```>BF`PA\(`"`3@`````````!@````````&````!@````8`(`3#P064(X
M````8````&!X@6(X>($B.0`8*7P@`()-````8`B`@ND``"PL(`""3:8""'RF
M`XE]$``!^.'_(?@8`$'X(02`3A@`0>@@`"$X$``!Z*8#"'P@`(!.``!"8`(`
M3#RP6$(X````8````&!X@6(X>(&".%`@@WQT'H1\=`Z$?)4!A'P@`()-````
M8!"`@ND``"PL(`""3:8""'RF`XE]$``!^.'_(?@8`$'X(02`3A@`0>@@`"$X
M$``!Z*8#"'P@`(!.````8```0F`"`$P\0%A".````&!X@2*)```)+"``@DRF
M`@A\````8!B`(NGH_Z'[\/_!^P``*2P0``'XP?\A^!@`0?@4`()!````8`"!
M8N@Y^/]+&`!!Z/__0CW__\(_````8("!(NE8?$HY4'S>.U!0WG___Z(_=![>
M?U!\O3O__]X[0/`I?#P`@$`X`.'[````8("!XCL!`"DY)!\J>0``/_DJ4)U]
MI@.)?2$$@$X8`$'H```_Z4#P*7S<_X!!.`#AZWW^_TL```!@((`BZ0``*2P4
M`()!_O]B/$P>8SA)]O]+&`!!Z$``(3@!`"`Y````8!```>CH_Z'K\/_!ZWB!
M(IFF`PA\(`"`3@```&````!@``!"8`(`3#PP5T(X````8"B`(ND``"DL/`""
M0:8""'P```!@_O]B/(B!@CA,'F,X$``!^.'_(?A=]/]+&`!!Z"``(3@0``'H
MI@,(?$#^_TL``$)@./[_2P(`3#S<5D(XI@((?!4S`$AY&WQ\L?\A^```P#LD
M`()!````8#"`(ND``,`[>".:?'CCA7\``*GK```]+!P`@D!0`"$X>//#?Q`S
M`$@]``DL%`""00$`I3@``"6)```)+.S_@D!0*+Q\>.N[?[0'OWP``-OK```^
M+,C_@D%X^^5_>..$?WCSPW]U]/]+&`!!Z````RPH`()`KO@^?3T`"2P<`()`
M4-B]?P$`_SMT'KU_%/K>?P``NI.(__]+"`![.[#__TL``````````8`&```"
M`$P\#%9".*8""'P0``'XD?\A^&0`@3CPCRWI:``A^0``(#D5__]+:`!!Z?"/
M+>EY2DI]```@.0P`@D&1\O]+&`!!Z'``(3@0``'HI@,(?"``@$X`````````
M`8`````"`$P\K%5".*8""'SP_\'[^/_A^W@;?WP0``'X@?\A^/"/+>EH`"'Y
M```@.60`P3MX\\1_>/OC?Z'^_TL``",L(`""0&@`0>GPCRWI>4I*?0``(#D\
M`()!%?+_2Q@`0>AF`$'I````8#"`(ND``"GI)!]*>?C_2CD44BE]$`!)Z0``
M*BP)`$GY]/^"0*3__TN``"$XN#$`2``````````!@`(```(`3#P(54(XI@((
M?#DQ`$C!_B'X>1M^?/"/+>GX`"'Y```@.6@`@D$``#Z)```)+%P`@D'U]O]+
M&`!!Z'D;?'Q,`()!_O]B/_[_0C_^_R(_"=Y[.PC>6CL+WCD[:``!.WCC@W]%
M]/]+&`!!Z'D;?WPX`()`>..#?S'R_TL8`$'H>//#?V7T_TL8`$'H^`!!Z?"/
M+>EY2DI]```@.=0`@D$I\?]+&`!!Z!,`_SMXVV1_>/OC?Q7W_TL8`$'H```#
M+*#_@D%XTT1_>/OC?_WV_TL8`$'H```#+(C_@D%X\\-_B??_2Q@`0>AX&WU\
M>/OC?WGW_TL8`$'H%!I]?`(`8SBT!V-\1??_2Q@`0>AX^^9_>//%?WC+)']X
M&WU\3?;_2Q@`0>AXPP1_>.NC?YWT_TL8`$'H__\#+'CKHW\H`()!@``A@28$
M*54`0`DL&`""0+G^_TMXZZ-_L?#_2Q@`0>@`__]+Q?+_2Q@`0>CH__]+0`$A
M.`@P`$@``````````8`(```"`$P\A%-".*8""'SX_^'[>!M_?!```?@Q_R'X
M*`"!./"/+>FX`"'Y```@.5GQ_TL8`$'H```@.0```RP\`()`0`!!@28$2E4`
M0`HH%`""0?__2&UX&VE\`*`(+!P`@D`"`(`X>/OC?QWU_TL8`$'H-`!C?'[9
M:52T!R-]N`!!Z?"/+>EY2DI]```@.0P`@D&U[_]+&`!!Z-``(3B,+P!(````
M``````&``0```@!,/-A20CBF`@A\#2\`2%'_(?AX&W]\>".>?/"/+>EH`"'Y
M```@.0``)(D]``DL"`""0`$`Q#MX\\-__?7_2Q@`0>AD`($X>!M]?'C[XW^U
M^_]+>1M\?$P`@D'=]?]+&`!!Z$`8/7RX`(%!``!`.:Y0/GVN43Q]/@8I50$`
M2CD```DL[/^"0&@`0>GPCRWI>4I*?0``(#EP`8)!_>[_2Q@`0>@```!@,(!B
MZP``(#D``#OK^/\9.7A+/'T!`"DY)!\J>2I02'T``"HL[/^"0````&"X@2*!
M`@"<.+0'A'PD'X1X```)+-P`@D%XRR-_*?/_2Q@`0>@``",L``![^(C_@D$!
M`#PY``!;Z0```#ED`(&3M`<I?20?*7DJ20I]>/OI?P``28D```HL#`""03T`
M"BS,`()`9@"!ZP```&`P@&+K4$@_?0(`?3BT!RE]%$IC?```6^O!]/]+&`!!
MZ"0?G'L``",L*N%Z?!S_@D$``#OI____.RK@*7T!`%^->$LH?0$`*3G__TF9
M_P!*<0P`@D$]``HLY/^"0#T`0#D``$B9````.:Y`7GVN04E]/@9*50$`"#D`
M``HL[/^"0,C^_TL!`"`Y````8'@C@WRX@2*11?3_2Q@`0>AY&WI\J/Z"0;0'
MA7]XRR1_)!^E>*GR_TL8`$'H``!;^PC__TL!`"DY(/__2[``(3A$+0!(````
M``````&`!P```@!,/+Q00CBF`@A\````8#B`(ND0``'XX?\A^```:8!][?]+
M&`!!Z````&!`@*+H_O_"//[_@CP8'<8X$=Z$.-WQ_TL8`$'H(``A.!```>BF
M`PA\(`"`3@`````````!@`````(`3#Q84$(XI@((?/C_X?L```!@.(#BZQ``
M`?C1_R'X``!_@!7M_TL8`$'H>?__2P``?X`%[?]+&`!!Z/[_XCS^_Z(\F.#G
M./[_@CP````Y>#OF?&2_I3@MWH0XO?/_2Q@`0>@P`"$XE"P`2``````````!
M@`$```(`3#S@3T(XI@((?"4L`$AAWR'X``#`._"/+>EX("'Y```@.9WR_TL8
M`$'H:`#A._[_PCS^_X(\>!ME?$+>QCA&WH0X>/OC?W`0H3OU\?]+&`!!Z``0
MH#AXZZ1_>/OC?V'M_TL8`$'H```#+#P`@$%X&W]\`0!C.+0'8WRE\O]+&`!!
MZ'D;?GP@`()!M`?_?WCKI']X^^5_:?+_2Q@`0>@``"`YKOD^?7@@0>GPCRWI
M>4I*?0``(#D,`()!Y>O_2Q@`0>B@("$X>//#?YPK`$@``````````8`#```"
M`$P\!$]"."3__TL````````````````"`$P\[$Y".*8""'PF@'!]"`!AD04K
M`$BA[B'X>!M^?/[_8CQ2WF,X>".??/"/+>GX$"'Y```@.;'X_TLO`(`X>!M[
M?'CSPW]E[O]+&`!!Z```(RPP`()!_O]B/'CSQ'];WF,XN?O_2_@00>GPCRWI
M>4I*?0``(#EX`8)!,>O_2Q@`0>AX\\-__O]"/\'Q_TL8`$'H:-Y:._[_(C_^
M_^(^_O_"/G@;?7QX^^-_@>S_2Q@`0>AXTT1_``"`.@``.RX)WCD[*>__2Q@`
M0>@````[`0"].VK>]SI&W]8Z>!M_?/@`@3MH`*$Z`("48@``/RQH_X)!```_
MB0``"2P(`()`>,L_?S0`DD%X^^1_>-MC?YWP_TL8`$'H```#+!P`@D!XTT1_
M``!@.,7N_TL8`$'H>!M_?+C__TMX^^-_$?'_2Q@`0>C__T,YM`=)?:Y('WTO
M``@LD`""010:/7W_#PDL^/Z!07CSQW]XN^9^>/OE?WBSQ'YXXX-_U>__2Q@`
M0>AXJZ1^>..#?R7N_TL8`$'H```#+(S_@D"``"&!)@0I50"@"7Q\_X)``0"`
M.'CC@W\][_]+&`!!Z````RQD_X)`_O]B/'CCA'];WF,X4?K_2WCC@W]9Z_]+
M&`!!Z'@;?GR(_O]+KDD??WA30WU8__]+8!$A.'CSPW\(`&&!((%P?5`I`$@`
M`````````X`,``!X&VE\>$LC?1```$@O``HL`0`I.?#_@D$``$F)```*+.S_
M@D`@`(!.`````````````````@!,/*A,0CBF`@A\^/_A^WD;?WP0``'XT?\A
M^!``@D$``#^)```)+!``@D#^_V(\"=YC.!0!`$C1[_]+&`!!Z/__(SD42K]\
M>!MI?!0:?WS__V,X0!@_?`P`@4'__S\L"`""0`$`(#D!`"DL__\I.;P`@D$`
M`$6)+P`*+*``@D%`*#]\4"@_?0$`*3D(`(%``0`@.0$`*2S__RDYD`""00``
M18G__P4Y+P`*+'@`@D#__T4Y4"@_?4!0/WP,`(%!__\_+`@`@D`!`"`Y`0`I
M+/__I3C__RDY$`""00``18DO``HLZ/^"05`HOWP``&`X`@`E.0`0*2A8`(%!
M````8`$`I3C`@2(Y>/OD?WA+(WT9[/]+&`!!Z#@``$C__Z4X2/__2WA#!7UL
M__]+0"@_?(#_@D```#^)_O]B/&K>8S@O``DLZ/Z"0:'I_TL8`$'H,``A./@G
M`$@``````````8`!```"`$P\1$M".*8""'P*`$`Y_O]B/&S>8SAY)P!(4?\A
M^/[_PC_^_Z(_C=[>.U+>O3O^_^(__O^"/ZG>_SNSWIP[\(\MZ8@`(?D``"`Y
M_O\B/1@=*3F85HE]&@!`.9A6"7R0`$$YT/\@.9A/BGW@_R`YF$\*?/[_(CU"
M'2FA@``AL2'U_TO^_V(\==YC.!7U_TO^_V(\?=YC.`GU_TO^_V(\AMYC./WT
M_TMX\\-_]?3_2_[_8CR=WF,XZ?3_2WCKHW_A]/]+>/OC?]GT_TMXXX-_T?3_
M2_[_8CR]WF,XQ?3_2_[_8CQ;WF,XN?3_2_[_8CS'WF,X3?3_2WD;9'P,`()!
M>..#?W'W_TO^_V(\V-YC.#'T_TMY&V1\$`""0?[_8CSJWF,X4??_2_[_8CSU
MWF,X$?3_2WD;9'PX`()!>.NC?S7W_TO^_X(\>//#?R'?A#@E]_]+B`!!Z?"/
M+>EY2DI]```@.5``@D&=YO]+&`!!Z/[_8CP%WV,XR?/_2WD;9'P,`()!>/OC
M?[C__TO^_X(\"@"@.!;?A#AQ`&$XR>?_2Q@`0>@```,LG/^"0'L`@3C4__]+
ML``A.!`F`$@``````````8`$```"`$P\?$E".````&`(@2*!__\)+&0`@D"F
M`@A\_O]B/*G>8S@0``'XH?\A^$WS_TL``$`Y```C+"``@D$``".)```)+!0`
M@D$P`"EI-``I?7[9*54!`"II````8&``(3@(@4*1$``!Z````&"F`PA\"H%B
MZ"``@$X```!@"H%BZ"``@$X``````````8`````"`$P\[$A".*8""'P0``'X
MX?\A^!GF_TL8`$'HL>S_2Q@`0>@``",L"`""00``8^@@`"$X$``!Z*8#"'P@
M`(!.``````````&``````@!,/*!(0CBF`@A\X20`2('_(?C^_X(_>!M_?"/?
MG#MXXX-_>?+_2WC[Y']Y&WY\$`""00``/HD```DL%`""0'CC@W^-]?]+@``A
M.-@D`$CQYO]+&`!!Z```(RSL_X)`>/OC?YWK_TL8`$'H>!M]?'CSPW^-Z_]+
M&`!!Z!0:?7P"`&,X7>O_2Q@`0>C^_\(\_O^"/$;?A#AX\\=_>!M]?&C>QCAX
M^^5_6>K_2Q@`0>AXZZ1_C/__2P`````````!@`0```(`3#S<1T(XI@((?```
M0#F8@4IA````.:"!"&'Y(P!(__\`//[_8C\0?@!@4MY[.W@;>GQXVV-_:@$A
M?!0*2GT4"@A]\(\MZ0``*OD``"`Y````8`B!(CD(`$`YH('A.YA6"7S__T`]
MP'Y*89A7"'P```!@((%"Z0```#F@@0AA%`H(?=!^7_D@`$`YF%9I?3``0#F8
M5HE]0`!`.9A6"7S__T`]\'Y*89A7:'T````Y$`!*.:"!"&$4"@A]F%>(?0``
M`#D0`$HYH($(810*"'V85PA\4`!`.9A6"7S__R`]V'XI89A/"'P```!@:($B
MZ>A^/_GE\/]+>1M^?$P`@D$``#Z)```)+$``@D$Y_O]+>//#?PGE_TL8`$'H
M>!M^?```(#F8@2EA%`HI?0``2>GPCRWI>4I*?0``(#GL!8)!7>/_2Q@`0>BQ
M_?]+T'Z_.WD;?GR4`8)!>//#?_[_@C_=Z?]+&`!!Z/__WCLZWYP[I`]C>`$`
M8SBEZ?]+&`!!Z'@;>7QX&WU\`0"^C```!2QP`8)`Z'Z_.PD`W>L``#XL/`""
M07CSPW\Q\/]+>1M^?.C_@D$``#Z)```)+-S_@D&A\O]+```#+-#_@D%X\\-_
M3>3_2Q@`0>AX&WY\N'Z?.P``/BP<`()`"0"\ZP``/2Q0`8)!```]B0``"2P@
M`8)`>//#?_[_`C\UZ?]+&`!!Z&K>&#MX&WQ\>,LC?R'I_TL8`$'H%!J<?P0$
MG#NT!YQ_>..#?^GH_TL8`$'H_O_B//[_@CQXRRA_/]_G.'C#!G]X\\5_1-^$
M.'@;?7SAY_]+&`!!Z,`!@#AXZZ-_4>;_2Q@`0>C__P,LT`""0('F_TL8`$'H
M``#C@!$`!RR\`()!````8$B`(ND``+KH_O^"/+0'YWQXZZ9_3=^$.```:>BM
MY_]+&`!!Z```P#MD_O]+&>__2WD;:7P@`()!```IB0``"2P4`()!1>/_2Q@`
M0>AY&WY\=/Z"0`D`?>@``",LT/^"0/[_PC\SW]X[7/[_2WCKHW^T!Z5\>..$
M?P(`O3LMY_]+&`!!Z'#^_TMXZZ-_0?'_2P```RS`_H)!>.NC?^WB_TL8`$'H
M>!M^?*3^_TL``,`[O/[_2R!_GSAXZZ-_C>+_2Q@`0>@```,L>!MW?"P`@D$`
M``!@2(`BZ0``NNC^_X(\>.NF?XC?A#@``&GHW>;_2Q@`0>@P__]+.'\_@28$
M*54`0`DLS/^"0#Q_WX-]X?]+&`!!Z``8'GRX_X)`.'\_@?X%*57``0DLJ/^"
M0'CC@W]9Y_]+&`!!Z'@;?GS^_V(\+M]C.`'N_TMY&V1\M`&"0```.NMXRR-_
M4>?_2Q@`0>@#``,L>!M\?(@`@4"T!V-\_O^"//S_8SC;WX0X%!IY?(GF_TL8
M`$'H```#+&0`@D`$`!PL&`""0?O_G#NT!YQ_KN`Y?2\`"2Q(`()`"`":ZP``
M/"P\`()!>..#?^WF_TL8`$'H`P`C*"@`@4#\_V,X_O^"/.#?A#@4&GQ\+>;_
M2Q@`0>@```,L"`""0'CCF7_E^?]+```#+.P!@D```(`X>,LC?P7A_TL8`$'H
M```#+'@;?'QX&WI\S`&"00(`H#CN_X`XI>3_2Q@`0>CX?S\[!@"@.'C+)']X
MXX-_#>+_2Q@`0>CX?S^)```)+,@`@D#Y?S^)0P`)++P`@D#Z?S^)00`)++``
M@D#[?S^)0P`)+*0`@D#\?S^)2``)+)@`@D#]?S^)10`)+(P`@D`"`*`XQO^`
M.'CC@W\QY/]+&`!!Z"D`H#AXRR1_>..#?YWA_TL8`$'H_O\"/7C+)W^8X`@Y
M_O^"/'C#!G]XZZ5_Y=^$.'CSPW_5Y/]+&`!!Z'CKHW]IW_]+&`!!Z'C;8W]X
M\\1_B>__2WCSPW^Y^?]+D/O_2P``>NAA\_]+>1MY?$C^@D!`_O]+``"@.```
M@#AXXX-____@.J7C_TL8`$'H^'\_.[0'6G\@!/=641H`2````&!X&WQ\>+OE
M?GC+)']XTT-_^>#_2Q@`0>@```,L<`"!07C30W^P?S\[H>#_2Q@`0>AXXX1_
M>,LC?_[_XC[(?U\[T1L`2````&```(`[.M_W.J[@N7QXTT-_>+OD?@$`G#L"
M`%H[!>3_2Q@`0>@4`#PHX/^"0```(#G^_P(]F.`(.<A__SCP?S^9^/[_2[0'
M97QXRR1_>..#?T4:`$@```!@9/__2_[_@CS^_V(\(=^$.*G>8SB%[O]+_O_B
M/_[_@C^8X/\[`N"<.R'D_TL8`$'H_O^"/'C[Z']XPP9_>.NE?W@;9WSTWX0X
M>//#?WWC_TL8`$'HP`&`.'CSPW_MX?]+&`!!Z/__`RR4_H)`'>+_2Q@`0>@`
M`".!$0`)+(#^@D#)X_]+&`!!Z`$`]SIX^^E_M`?H?GC#!G]X&V=\>.NE?WCC
MA']X\\-_(>/_2Q@`0>BD__]+```AZ'CSPW\<'0!(``````````&`"0```@!,
M/)Q`0CBF`@A\X1P`2('_(?@```!@.(#BZP``?X!=W?]+&`!!Z'@;?GP``'^`
M3=W_2Q@`0>BP`#Z)L0`CF?[_8CR-WF,X4>K_2P``(RP<`()!```CB3$`"2P0
M`()``0`CB0``"2P(`()!]?3_2P``?X`)W?]+&`!!Z/[_@CP#`,`X`0"@.!/@
MA#BQX_]+&`!!Z'D;?GQ8`()!``!_@-W<_TL8`$'H$``^Z?[_HCP5X*4X``")
MZ$7>_TL8`$'H$``^Z0``*>D,`"F!0``I=2``@D$``'^`I=S_2Q@`0>@0`#[I
M``")Z/7A_TL8`$'H``!_@(G<_TL8`$'H_O^"/`,`P#@!`*`X&N"$.#'C_TL8
M`$'H>1M^?'0`@D'^_V(\6]YC.'7I_TMY&WU\*`""00``?X!)W/]+&`!!Z!``
M/NEXZZ5_``")Z+7=_TL8`$'H/```2''O_TMY&WU\``!_@-``@D$9W/]+&`!!
MZ!``/NEXZZ5_``")Z(7=_TL8`$'H>.NC?QG<_TL8`$'H``!_@.W;_TL8`$'H
M>!M^?```?X#=V_]+&`!!Z/[_@CP!`*`X'."$.&GB_TL8`$'H_O^B/#'@I3AX
M&V1\>//#?S'=_TL8`$'H``!_@*7;_TL8`$'H```@.;$`(YG^_V(\4MYC.*GH
M_TL```!@```C+,B18OA,`()`````8,"18NB]]O]+````8```(RS(D6+X,`""
M0/[_8CPWX&,XE=O_2Q@`0>A-V_]+&`!!Z````&#`D4+I$``^Z0``JNC\_O]+
M````8,B18NC``8`X)=__2Q@`0>@1``,L>!MF?#0`@D$!`",Y`0`)*"@`@4``
M``!@P)$BZ0```&#(D:+H_O]B/%C@8S@``(GH*=O_2Q@`0>B``"$XA!H`2```
M```````!@`,```(`3#SL/4(XI@((?/#_P?OX_^'[>!M_?!```?B1_R'X+?'_
M2^WP_TMX&WY\3?3_2P```RQ0`()!```_+$@`@D$``#^)```)+#P`@D'^_X(\
M>//#?S_?A#@UW/]+&`!!Z``8/GP@`()`<``A.'C[XW\0``'H\/_!Z_C_X>NF
M`PA\;.C_2W``(3@$&@!(``````````&``@```@!,/%0]0CBF`@A\.`##.(D9
M`$@A_2'X\(\MZ:@"(?D``"`Y"``@.:8#*7TH``$Y+#0@?0``1ND0``@Y"`#&
M."``*7DB`$=Y\/\H^2#"27D@1DIY+@0I57A3*7THP.IX>%,I?1Y"YU1X.RE]
M^/\H^<#_`$)``"`Y(``!.:8#*7UP`"CI2`#HZ!@`2.EX.BE]>%(I?0D`2.EX
M4BE]I`\J><(/*7EX2TE](``I>8``*/G0_P!"``!CZ2``@^@0`./H&`##Z`@`
MH^@P`.'K.`#!Z\(N:7FD+FAY>$L(?2@`(>F"\*IX(``(>8):_S^9>?\[@EK>
M/X):*3T4,O]_F7DI.9EYWCL4(BE]%#K>?Q1*"'UX,NE\."@I?7@R*7T42@A]
M9/"I>'A3*7T@`!UY(``@>7@"ZGPX6$I]>#I*?13Z2GW(+A]YXBX(>7A#Z'^"
M\']Y%$)*?63P:'EX^PA](`!:>7A"*7T@`!]Y..@I?7@"*7T4\BE]R"Y>>>(N
M2GEX4\I_%%(I?63PJGN"\+U[(``[>7CK2GU``*'K>%((?2``7GDXT`A]@EJ]
M/WCZ"'V9>;T[%`*]?\@N('GB+BEY%.H(?7A+"7P42@A]9/!)>X+P6GL@`!QY
M>-,I?7A*0'U(`$'I(``]>3C8`'QX\@!\@EI*/9EY2CD4^DI]%%(`?,@N"GGB
M+@AY>$-*?112`'QD\&I[@O![>R``&GAXVTI]>%(H?5``(>D@`%]Y..`(?7CJ
M"'V"6BD]F7DI.13R*7T42@A]R"X)>.(N`'AX`RE]%$H(?63PB7N"\)Q[(``;
M>7CC*7UX2D!]6`!!Z2``/GDXT`!\>/H`?():2CV9>4HY%.I*?112`'S(+@IY
MXBX(>7A#2GT44@!\9/!*>X+P6GL@`!QX>--*?7A2*'U@`"'I(`!=>3C8"'UX
M\@A]@EHI/9EY*3D4^BE]%$H(?<@N"7CB+@!X>`,I?11*"'UD\&E[@O![>R``
M&GEXVRE]>$I`?6@`0>D@`#]Y..``?'CJ`'R"6DH]F7E*.13R2GT44@!\R"X*
M>>(N"'EX0TI]%%(`?&3PBGN"\)Q[(``;>'CC2GUX4BA]<``AZ2``7GDXT`A]
M>/H(?8):*3V9>2DY%.HI?11*"'W(+@EXXBX`>'@#*7T42@A]9/!)>X+P6GL@
M`!QY>-,I?7A*0'UX`$'I(``]>3C8`'QX\@!\@EI*/9EY2CD4^DI]%%(`?,@N
M"GGB+@AY>$-*?112`'QD\&I[@O![>R``&GAXVTI]>%(H?8``(>D@`%]Y..`(
M?7CJ"'V"6BD]F7DI.13R*7T42@A]R"X)>.(N`'AX`RE]%$H(?63PB7N"\)Q[
M(``;>7CC*7UX2D!]B`!!Z2``/GDXT`!\>/H`?():2CV9>4HY%.I*?112`'S(
M+@IYXBX(>7A#2GT44@!\9/!*>X+P6GL@`!QX>--*?7A2*'V0`"'I(`!=>3C8
M"'UX\@A]@EHI/9EY*3D4^BE]%$H(?<@N"7CB+@!X>`,I?11*"'UD\&E[@O![
M>R``&GEXVRE]>$I`?9@`0>D@`#]Y..``?'CJ`'R"6DH]F7E*.13R2GT44@!\
MR"X*>>(N"'EX0TI]%%(`?&3PBGN"\)Q[(``;>'CC2GUX4BA]H``AZ2``7GDX
MT`A]>/H(?8):*3V9>2DY%.HI?:@`H>L42@A]R"X)>.(N`'AX`RE]@EJ]/Q1*
M"'UD\$E[@O!:>YEYO3MXTRE](``<>7A*2GT4^KU_.-A*?<@N'WEX\DI]XBX(
M>7A#Z'\4ZDI]%$)*?63P:'N"\'M[(``@>7C;"'VP`&'K(`!=>7A"*7T@`!]Y
M..`I?8):>S]X`BE]F7E[.Q3R>W_(+EYYXBY*>13:*7UX4\I_%%(I?63PBGN"
M\)Q[(``[>7CC2GVX`('K>%((?2``7GDXZ`A]@EJ</WCZ"'V9>9P[%`*<?^(N
M('DH*"EY%.((?7@#*7UD\*![@O"]>Q1*"'UXZP!\9/!\>W@"27W``$'I.-@I
M?8+P>WMX\BE]>-N<?X):2CV9>4HY%/I*?>(N'WD44BE]*"@*>7C[2GUXXA]\
M%%(I?<@`0>EX0O]_(`#_>R```'B(\#UYVFY*/:'K2CD4\DI]XBX^>112_W\H
M*"IY>/-*?8CP'GD44O]_T`!!Z:+P"'EX0]Y_>/*(?R``G'O:;DH]>$H(?:'K
M2CD@``AY%`)*?>(NX'L40DI]*"CH>W@#"'VB\"EY%$(*?-@`0>EX2[U_>.K)
M?^(N"'AX^BE](`#>>]IN2CT@`"EYH>M*.13B2GV(\/Q[%$I*?2@H"7AX0RE]
MHO#H>Q1**GW@`$'I>$.<?WCBJ'_B+C]Y>`((?2``O7O:;DH](``(>:'K2CD4
M\DI]B/`>>!1"2GTH*"AY>/L(?:+P`'@40@I]Z`!!Z7@#WG]X\H!_XBX?>7A*
M`'P@`)Q[VFY*/2```'BAZTHY%.I*?8CP/7FB\"EY%`)*?7A+O7_P`"'I*"@`
M>7C[`'P4`NI_>.K*?]IN*3UX0DI]H>LI.2``2GD4XBE]XB[@>Q12*7TH*.I[
M>`-*?8CP''D44@E\^``AZ:+P"'EX0YQ_(`#>>WCBJG_B+@AXVFXI/7CZ2GVA
MZRDY(`!*>13R*7V(\/Y[%%(I?2@H"GAX0TI](`"]>Q12"7T``2'IHO#J>WA3
MWG_B+A]Y>/**?R``G'O:;BD]>`)*?:'K*3D@`$IY%.HI?8CP'7@44BE]*"@*
M>7C[2GVB\`!X%%))?0@!(>EX`[U_>.K`?^(N7WEX0@!\(`#>>]IN*3T@``!X
MH>LI.13B*7T4`BE]*"A`>7C[`'R(\!]Y%`()?!`!(>FB\`AY>$/_?WCZJ'\@
M`+U[VFXI/7A2"'VAZRDY(``(>13R*7WB+AYX%$(I?2@H"'AX\PA]B/!>>11"
M"7T8`2'IHO!*>7A3WG]X\NI_(`#_>]IN*3UX`DI]H>LI.2``2GD4ZBE]XBX=
M>112*7TH*`IY>.M*?8CP'7@44DE](`$AZ:+P`'AX`[U_>.K`?R``WGO:;BD]
M>$(`?*'K*3D@``!X%/HI?>(N7WD4`BE]*"A`>7C[`'R(\!]Y%`()?"@!(>FB
M\`AY>$/_?WCZJ'\@`+U[VFXI/7A2"'VAZRDY(``(>13R*7WB+AYX%$(I?2@H
M"'AX\PA]B/!>>11""7TP`2'IHO!*>7A3WG]X\NI_(`#_>]IN*3UX`DI]H>LI
M.2``2GD4ZBE]XBX=>112*7TH*`IY>.M*?8CP'7@44DE].`$AZ:+P`'AX`[U_
M>.K`?R``WGO:;BD]>$(`?*'K*3D@``!X%/HI?>(N7WD4`BE]*"A`>7C[`'R(
M\!]Y%`()?$`!(>FB\`AY>$/_?XCP&WAX^JA_(`"]>]IN*3UX4@A]H>LI.2``
M"'D4\BE]XBX>>!1"*7TH*`AX>/,(?8CP7GD40@E]2`$AZ:+P2GEX4]Y_>/+J
M?R``_WO:;BD]>`)*?:'K*3D@`$IY%.HI?>(N'7D44BE]*"@*>7CK2GVB\`!X
M%%))?5`!(>EX`WM_>-K`?R``WGMX0@!\B/!,>=IN*3T@``!XH>LI.13Z*7WB
M+E]Y%`(I?2@H0'EX^P!\B/`?>10"B7]8`2'IHO`(>7A#_W_B+HA[VFXI/:'K
M"3AX^FE_>%(I?13R`'P@`"EYHO!*>11*`'S(+HE[>$,I?7A3C'T42@!\8`$A
MZ2``>WL@`!UXB/"(>R``GGG:;DD]>&+I?WCB*7VAZTHY%-I*?2``*7EH`6'K
M%$I*?<@N"7CB+@!X(`#_>W@#*7T42DI]HO")>WA+"'T;CR`]W+PI82``''D@
M`"EY>$.`?13::7\XX(Q]..@`?!3Z^W]X8P!\(`!:>13Z`'S(+E]YXBY*>7A3
MZG]D\+][@O"]>Q120'UXZ_]_(`!,>7C["'TXX.!_.-`(?2``_7MX`PA]<`$!
MZ!0""7P4\@!\%`((?<@N0'GB+DIY>%,*?!12"'UD\$I[@O!:>R``&WEXTTI]
M(`!>>7A3X'\X8`!\./#_?WC[`'QX`>'K%/KI?Q3B_W\4^@!\R"X?>>(N"'EX
M0^A_9/"?>8+PC'D40@!\>&/_?R``&GAX^TA]./#J?SC8"'T@`/Q[>%,(?8`!
M0>D44DE]%.I*?112"'W(+@IXXBX`>'@#2GT44@A]9/!J>X+P>WL@``QY>-M*
M?2``77EX4^!_.-``?#CH_W]X^P!\B`'AZQ3ZZ7\4\O]_%/H`?,@N'WGB+@AY
M>$/H?V3P7WN"\%I[%$(`?'C3_W\@`!MX>/M(?3CHZG\X8`A](`#^>WA3"'V0
M`4'I%%))?13B2GT44@A]R"X*>.(N`'AX`TI]%%((?63PBGF"\(QY(``:>7AC
M2GT@`%QY>%/@?SC8`'PXX/]_>/L`?)@!X>L4^NE_%.K_?Q3Z`'S(+A]YXBX(
M>7A#Z']D\'][@O![>Q1"`'QXV_]_(``,>'C[2'TXX.I_.-`(?2``_7MX4PA]
MH`%!Z11227T4\DI]%%((?<@N"GCB+@!X>`-*?112"'UD\$I[@O!:>R``&WEX
MTTI](`!>>7A3X'\X8`!\./#_?WC[`'RH`>'K%/KI?Q3B_W\4^@!\R"X?>>(N
M"'EX0^A_9/"?>8+PC'D40@!\>&/_?R``&GAX^TA]./#J?SC8"'T@`/Q[>%,(
M?;`!0>D44DE]%.I*?112"'W(+@IXXBX`>'@#2GT44@A]9/!J>X+P>WL@``QY
M>-M*?2``77EX4^!_.-``?#CH_W]X^P!\N`'AZQ3ZZ7\4\O]_%/H`?,@N'WGB
M+@AY>$/H?V3P7WN"\%I[%$(`?'C3_W\@`!MX>/M(?3CHZG\X8`A](`#^>WA3
M"'W``4'I%%))?13B2GT44@A]R"X*>.(N`'AX`TI]%%((?63PBGF"\(QY(``:
M>7AC2GT@`%QY>%/@?SC8`'PXX/]_>/L`?,@!X>L4^NE_%.K_?Q3Z`'S(+A]Y
MXBX(>7A#Z']D\'][@O![>Q1"`'QXV_]_(``,>'C[2'TXX.I_.-`(?2``_7MX
M4PA]T`%!Z11227T4\DI]%%((?<@N"GCB+@!X>`-*?112"'UD\$I[@O!:>R``
M&WEXTTI](`!>>7A3X'\X8`!\./#_?WC[`'S8`>'K%/KI?Q3B_W\4^@!\R"X?
M>>(N"'EX0^A_9/"?>8+PC'D40@!\>&/_?R``&GAX^TA]./#J?SC8"'T@`/Q[
M>%,(?>`!0>D44DE]%.I*?112"'W(+@IXXBX`>'@#2GT44@A]9/!J>X+P>WL@
M``QY>-M*?2``77EX4^!_.-``?#CH_W]X^P!\Z`'AZQ3ZZ7\4\O]_9/!>>X+P
M6GL4^@!\>-/>?\@N'WGB+@AY>/-*?7A#Z'\X8$I]%$(`?3CHP']X`TI]\`$!
MZ"``&WD@`-][%`()?!3B`'P4`DI]R"X`>>(N"'EX0PA\%$)*?63PB'F"\(QY
M(`!<>7AC"'T@``QY>$/`?SC8`'PX8-Y_>/,`?/@!P>L4\LE_%.K>?Q3R`'SB
M+EYY*"A*>7CS2GT44@!\9/!J>X+P>WMXVTI]>%,(?3A@77TXX`A](`!>>7CK
M"'T``J'K%.HI?13Z*7WB+A]X%$H(?2@H"7AX^RE]9/"?>Q1*"'V"\(E[>$O\
M?P@"X>MBRB`]UL$I87CB2GT@`"EY>`)*?13ZZ7\@`$IY%&+_?^(N'7D4^DI]
M*"@?>7CK_W^(\!UX%/I*?:+P`'@0`N'K>`.]?WCJ@'\@`)Q[>$(`?!3ZZ7\4
M\O]_(```>.(N7GD4^@!\*"A?>7CS_W^(\!YYHO`(>13Z`'QX0]Y_&`(!Z7CR
MOW\@`+U[>%+_?Q1""7T@`/][%.((?>(N''@4^@A]*"@?>'CC_W\4^@A]B/!?
M>:+P2GGB+AQY>%/_?R`"0>D44DE]%.I*?7CZW7]X`KU_(`#>>R``O7L4ZDI]
M*"@=>7CCO7\4ZDI]B/`=>*+P`'CB+EQY>`.]?R@"`>@4`@E\%/(`?'CJ_G]X
M0MY_(`#_>R``WGL4\@!\*"A>>7CCWG\4\@!\B/`>>:+P"'GB+AQX>$/>?S`"
M`>D40@E]%/H(?7CROW]X4O]_(`"]>R``_WL4^@A]*"@?>'CC_W\4^@A]B/!?
M>:+P2GGB+AQY>%/_?S@"0>D44DE]%.I*?7CZW7]X`KU_(`#>>R``O7L4ZDI]
M*"@=>7CCO7\4ZDI]B/`=>*+P`'CB+EQY>`.]?T`"`>@4`@E\%/(`?'CJ_G]X
M0MY_(`#_>R``WGL4\@!\*"A>>7CCWG\4\@!\B/`>>:+P"'GB+AQX>$/>?T@"
M`>D40@E]%/H(?7CROW]X4O]_(`"]>R``_WL4^@A]*"@?>'CC_W\4^@A]B/!?
M>:+P2GGB+AQY>%/_?U`"0>D44DE]%.I*?7CZW7]X`KU_(`#>>R``O7L4ZDI]
M*"@=>7CCO7\4ZDI]B/`=>*+P`'CB+EQY>`.]?U@"`>@4`@E\%/(`?'CJ_G]X
M0MY_(`#_>R``WGL4\@!\*"A>>7CCWG\4\@!\B/`>>:+P"'GB+AQX>$/>?V`"
M`>D40@E]%/H(?7CROW]X4O]_(`"]>R``_WL4^@A]*"@?>'CC_W\4^@A]B/!?
M>:+P2GGB+AQY>%/_?V@"0>D44DE]%.I*?7CZW7]X`KU_(`#>>R``O7L4ZDI]
M*"@=>7CCO7\4ZDI]B/`=>*+P`'CB+EQY>`.]?W`"`>@4`@E\%/(`?'CJ_G]X
M0MY_(`#_>R``WGL4\@!\*"A>>7CCWG\4\@!\B/`>>:+P"'GB+AQX>$/>?W@"
M`>D40@E]%/H(?7CROW]X4O]_(`"]>R``_WL4^@A]*"@?>'CC_W\4^@A]B/!?
M>:+P2GGB+AQY>%/_?X`"0>D44DE]%.I*?7CZW7]X`KU_(`#>>R``O7L4ZDI]
M*"@=>7CCO7^(\!QXHO``>!3J2GUX`YQ_B`(!Z.(N77D4`@E\%/(`?'CB_G]X
M0MY_(`#_>R``WGL4\@!\*"A>>7CKWG^(\!UYHO`(>13R`'QX0[U_D`(!Z>(N
M'G@40@E]%/H(?7CJGW]X4O]_(`"<>R``_WL4^@A]*"@?>'CS_W^(\%YYHO!*
M>13ZZ']X4]Y_F`)!Z7CRJ'\@`+U[>`((?11227T@``AY%.)*?>(N_'L40DI]
MR"[H>WCC"'T40DI]B/`(>*+P`'AX`PA]H`(!Z!0"*7WB+D!Y%%HI?7A"RW]X
M^FM]%.HI?2``:WD4,@A]%%HI?<@N2WD4*DI]>`-K?2``2GD46BE](``I>:+P
MY7L(`$/YB/#J>R``"'EX*TI]```C^10B/GT4.DI](``I>1@``_D@`$IY(``C
M^1``0_FH`D'I\(\MZ7E*2GT``"`Y#`""0:7$_TL8`$'HX`(A.%0$`$@`````
M`````8`&```"`$P\R"=".*8""'R``&`X$``!^.'_(?CQRO]+&`!!Z$5G0#T@
M`"$X`2-*80``0_G-[T`]B:M*82``2GD(`$/YNIA`/?[<2F$@`$IY$`!#^3(0
M0#UV5$IA&`!#^=+#0#WPX4IA(`!*>2``0_D``$`Y>`!#D2@`0_DP`$/Y$``!
MZ*8#"'P@`(!.``````````&``````@!,/#0G0CBF`@A\)!^I>&4#`$BA_R'X
M>!M_?'@CF7QX*[Y\*`!#Z112*7T@`"EY0$@J?!``@4`P`$/I`0!*.3``0_EX
M`'^`*``_^3``/^E"'\I[.`"?.P```RP44BE],``_^5@`@D%``*,C`/`=?`@`
M@4!X\]U_M`>[?[0'8WQXVV5_>,LD?Q0:?'S)R?]+&`!!Z'@`/X$42CU]0``)
M+'@`/Y%$`()`4/"]?WC[XW^T![Y_%-HY?S'I_TL0`*`[(`!@.S``0#L_`!XL
M)`"!07CSQ7]XRR1_>..#?WG)_TL8`$'H>`#?DV``(3C``@!(F,Y`?9CN>7W`
M_]X[>/OC?YC>F7V8UAE\M`?>?T``.3N8YT!]F.]\?9C?G'V8UQQ\R>C_2Z3_
M_TL``````````8`'```"`$P\`"9".*8""'PH`"0Y@/]`.34"`$BQ_R'X.`"D
M.W@;?GQX(Y]\+$R`?S``)#DL3&!_*``DZ;[N*54!`*DXM`<I?3@`!2RT!Z-\
MKDE=?10:?7PT`8%`0`"E(```@#BT!Z5\G<C_2Q@`0>AX^^-_1>C_2S@`H#@`
M`(`X>.NC?X'(_TL8`$'H<`!_DW0`GY-X^^-_(>C_2P``/^EX^^-_`D8I>0``
M/ID``#_I`H0I>0$`/ID``#_I`L(I>0(`/ID``#_I`P`^F0@`/^D"1BEY!``^
MF0@`/^D"A"EY!0`^F0@`/^D"PBEY!@`^F0@`/^D'`#Z9$``_Z0)&*7D(`#Z9
M$``_Z0*$*7D)`#Z9$``_Z0+"*7D*`#Z9$``_Z0L`/ID8`#_I`D8I>0P`/ID8
M`#_I`H0I>0T`/ID8`#_I`L(I>0X`/ID8`#_I#P`^F2``/^D"1BEY$``^F2``
M/^D"A"EY$0`^F2``/^D"PBEY$@`^F2``/^D3`#Z9B<'_2Q@`0>A0`"$X_```
M2#@`I2```(`XM`>E?.S^_TL``````````8`%``````!@````8````&````!@
M````8````&````!@`@!,/$`D0CC__X(]0'R,Z?C_X?O__^(_T?\A^$A\_SO_
M_RPL/`""0:8""'P8`$'X^/__.T```?@```!@``!"8*8#B7TA!(!.&`!!Z/G_
MG^G__RPL[/^"0$```>BF`PA\,``A./C_X>L@`(!.H/^!^JC_H?JP_\'ZN/_A
M^L#_`?O(_R'[T/]!^]C_8?O@_X'[Z/^A^_#_P?OX_^'[$``!^"``@$Z@_X'J
MJ/^AZK#_P>JX_^'JP/\!Z\C_(>O0_T'KV/]AZ^#_@>L0``'HZ/^AZZ8#"'SP
M_\'K^/_AZR``@$[P_\'K$``!Z/C_X>NF`PA\(`"`3@```&!8H0$``````*8"
M"'P%`)]"I@)H?:8#"'SP_POH4&"+?11:8'W4_PPX``"+Z8+P`'BF`XE]"`!K
MZ2`$@$[,__]+R/__2\3__TO`__]+O/__2[C__TNT__]+L/__2ZS__TNH__]+
MI/__2Z#__TN<__]+F/__2Y3__TN0__]+C/__2XC__TN$__]+@/__2WS__TMX
M__]+=/__2W#__TML__]+:/__2V3__TM@__]+7/__2UC__TM4__]+4/__2TS_
M_TM(__]+1/__2T#__TL\__]+./__2S3__TLP__]++/__2RC__TLD__]+(/__
M2QS__TL8__]+%/__2Q#__TL,__]+"/__2P3__TL`__]+_/[_2_C^_TOT_O]+
M\/[_2^S^_TOH_O]+`@!,/"0B0CBF`@A\$``!^.'_(?C9R?]+````8"``(3@0
M``'HI@,(?"``@$XN+@`E<R\E<P!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D
M97(`26YT97)N86QS.CI005(Z.D)/3U0`97AE`"]P<F]C+R5I+R5S`%!!4E]4
M14U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)0@!015),-4]0
M5`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!
M3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,
M3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%35``4$%27T=,
M3T)!3%]#3$5!3@!005)?0TQ%04X]`#$`3$1?3$E"4D%265]0051(`%-94U1%
M30`E,#)X`'!A<BT`)7,E<R5S)7,`)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@
M<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@`E<SH@<')I=F%T
M92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET
M(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*`'!A<FP`+G!A<@`E<R5S8V%C
M:&4M)7,E<P`E<R5S=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,`&`!P97)L
M`#``4$%2.CI086-K97(Z.E9%4E-)3TX`,2XP-30`56YA8FQE('1O(&-R96%T
M92!C86-H92!D:7)E8W1O<GD`)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C
M:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@`M90`M+0!5
M4T52`%5315).04U%`%1%35!$25(`5$U0`"]T;7``979A;"`G97AE8R`O=7-R
M+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI
M;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!
M4E]-04=)0RP@)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE+"`E36]D
M=6QE0V%C:&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I
M<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER
M92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I
M<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F:6QE<R!I;B`B
M)'!A<E]T96UP(ETI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M
M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A
M<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I
M('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP
M6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I
M<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIM>2`D9FEL
M96YA;64@/2`D=&UP+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\/"(N+BXB.PIX
M/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M
M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L
M965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL96YA;64G"BXN
M+@IC;&]S92`D=&UP.PIC:&UO9"`P-S`P+"`D9FEL96YA;64["FUY("1C;60@
M/2`B)&9I;&5N86UE(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES=&5M*"1C;60I
M.PIO=71S*'%Q6U-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O
M<FT@8VQE86YU<#H@)&9I;&5N86UE72D["GT*?2!]"D)%1TE.('L*)%!!4E]-
M04=)0R`](")<;E!!4BYP;5QN(CL*26YT97)N86QS.CI005(Z.D)/3U0H*2!I
M9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?
M:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@
M)7-Y<R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[
M)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/
M4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D
M7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O
M9VYA;64H*3L*;W5T<RAQ<5M<)'!R;V=N86UE(#T@(B1P<F]G;F%M92)=*3L*
M7W-E=%]P87)?=&5M<"@I.PIO=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D
M14Y6>U!!4E]414U0?2)=*3L*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD[
M"DU!1TE#.B!["FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIU;FQE
M<W,@*&]P96X@7T9(+"`G/#IR87<G+"`D<')O9VYA;64I('L*;W5T<RAQ<5M#
M86XG="!R96%D(&9R;VT@9FEL92`B)'!R;V=N86UE(ETI.R`@(R!D;VXG="!U
M<V4@)"$@:&5R92!A<R!I="!R97%U:7)E<R!%<G)N;RYP;0IL87-T($U!1TE#
M.PI]"FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D8G5F.PIM>2`D
M<VEZ92`]("US(%]&2#L*;7D@)&UA9VEC7W!O<R`]("1S:7IE("T@)'-I>F4@
M)2`D8VAU;FM?<VEZ93L@(R!.3U1%.B`D;6%G:6-?<&]S(&ES(&$@;75L=&EP
M;&4@;V8@)&-H=6YK7W-I>F4*=VAI;&4@*"1M86=I8U]P;W,@/CT@,"D@>PIS
M965K(%]&2"P@)&UA9VEC7W!O<RP@,#L*<F5A9"!?1D@L("1B=68L("1C:'5N
M:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN
M9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P*2!["B1M86=I8U]P;W,@*ST@
M)&D["FQA<W0["GT*)&UA9VEC7W!O<R`M/2`D8VAU;FM?<VEZ93L*?0II9B`H
M)&UA9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T
M<FEN9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T
M($U!1TE#.PI]"G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"P@,#L*<F5A9"!?
M1D@L("1B=68L(#0["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"`M('5N<&%C
M:R@B3B(L("1B=68I+"`P.PHD9&%T85]P;W,@/2!T96QL(%]&2#L*;7D@)7)E
M<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@*"1B
M=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@
M)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68[
M"F]U=',H<7%;56YP86-K:6YG($9)3$4@(B1F=6QL;F%M92(N+BY=*3L*;7D@
M)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@
M)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M
M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A
M9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D
M97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@
M)&9I;&5N86UE(#T@7W-A=F5?87,H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D[
M"B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M
M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN
M86UE.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@
M9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*;7D@)&9I;&5N86UE(#T@7W-A
M=F5?87,H(B1B87-E;F%M921E>'0B+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,
M24(Z("1F:6QE;F%M95QN(BD["GT*96QS92!["B1-;V1U;&5#86-H97LD9G5L
M;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@
M)&9U;&QN86UE+`I].PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97TK*SL*?0IR
M96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D
M<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R
M("$D;6]D=6QE.PIM>2`D:6YF;R`]("1-;V1U;&5#86-H97LD;6]D=6QE?3L*
M<F5T=7)N('5N;&5S<R`D:6YF;SL*9&5L971E("1R97%U:7)E7VQI<W1[)&UO
M9'5L97T["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE
M(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z
M.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I
M92`B0V%N)W0@8W)E871E('1E;7`@9FEL93H@)"$B.PHD9F@M/F)I;FUO9&4H
M*3L*)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E96LH,"P@,"D[
M"G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]S879E7V%S
M*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PHD:6YF;RT^>V9I
M;&5](#T@)&9I;&5N86UE.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&5N
M86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL96YA;64B.B`D(5T["G)E
M='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N)W0@
M9FEN9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO
M861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y
M.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?
M9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I
M;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE
M<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I
M('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I
M;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M
M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER
M95]L:7-T>R1F:6QE;F%M97T["GT*=6YL97-S("@D8G5F(&5Q(")02UPP,#-<
M,#`T(BD@>PIO=71S*'%Q6TYO('II<"!F;W5N9"!A9G1E<B!&24Q%('-E8W1I
M;VX@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#(#L*?0HD<W1A
M<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@("`@("`@("`@(",@<W1A
M<G0@;V8@>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@
M)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D55
M4T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B
M;&5M*0HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["FEF("@A
M)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F
M('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R
M"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P
M87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E
M<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]21553
M17T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA
M=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP
M72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H
M)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D
M,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G
M*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G
M*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@
M/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L
M;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF
M("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92!Q
M<5M#86XG="!O<&5N(&QO9R!F:6QE("(D,B(Z("0A73L*?0IE;'-I9B`H)#$@
M97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII
M9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!
M4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)0
M05(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T
M.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.
M0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z
M.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ
M4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD
M969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1P87(@;W(@
M9&EE('%Q6T-A;B=T(&9I;F0@<&%R(&9I;&4@(B1P87(B.B`D(5T["F)L97-S
M*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*
M*"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H
M:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z
M:7`@87)C:&EV92`B)'!A<B)=.PI]"FUY("5E;G8@/2!D;R!["FEF("@D>FEP
M(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2![
M"B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M
M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FEF("AD
M969I;F5D("1P87(I('L*;W!E;B!M>2`D<&@L("<\.G)A=R<L("1P87(@;W(@
M9&EE('%Q6T-A;B=T(')E860@<&%R(&9I;&4@(B1P87(B.B`D(5T["FUY("1B
M=68["G)E860@)'!H+"`D8G5F+"`T.PID:64@<7%;(B1P87(B(&ES(&YO="!A
M('!A<B!F:6QE72!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["F-L;W-E
M("1P:#L*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M
M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/
M7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D
M:64@<7%;0V%N)W0@8W)E871E(&9I;&4@(B1O=70B.B`D(5T["B1F:"T^8FEN
M;6]D92@I.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<CL*:68@*&1E9FEN
M960@)&1A=&%?<&]S*2!["G)E860@7T9(+"`D;&]A9&5R+"`D9&%T85]P;W,[
M"GT@96QS92!["FQO8V%L("0O(#T@=6YD968["B1L;V%D97(@/2`\7T9(/CL*
M?0II9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_
M.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`[
M"E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*
M?0IF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V86P@
M/2`D96YV>R1K97E](&]R(&YE>'0["B1V86P@/2!E=F%L("1V86P@:68@)'9A
M;"`]?B`O7ELG(ETO.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D
M:V5Y*2`N(")?7R(["FUY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(]
M)'9A;"(["B1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E
M="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*
M?0HD9F@M/G!R:6YT*"1L;V%D97(I.PII9B`H)&)U;F1L92D@>PIR97%U:7)E
M(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*
M:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P
M('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(*
M*"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@
M)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\
M9RP@<WPO)'Q\(&9O<F5A8V@@0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]
M*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S
M("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1]
M.R`@("`@("`@(",@6%A8(&QI8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E
M;CL*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D
M9FEL92P@)&YA;64I.PII9B`H9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1K97E]*2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y
M+"`D9F,I.PI]"F5L<V4@>PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@
M*"1K97D@/7X@;7Q>7%$D9&ER7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE
M*2`]("@D:V5Y+"`D,2D["FQA<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO861E
M<B];7B]=*R\H+BHI)'PI('L*:68@*&UY("1R968@/2`D36]D=6QE0V%C:&5[
M)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0II
M9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q
M(BP@)#$I.PIL87-T.PI]"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA
M;64["FYE>'0@:68@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D
M9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS
M<')I;G1F*'%Q6U!A8VMI;F<@1DE,12`B)7,B+BXN72P@<F5F("1F:6QE(#\@
M)&9I;&4M/GMN86UE?2`Z("1F:6QE*2D["FUY("1C;VYT96YT.PII9B`H<F5F
M*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*
M;&]C86P@)"\@/2!U;F1E9CL*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE
M(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL92(Z("0A73L*)&-O;G1E;G0@
M/2`\)&9H/CL*8VQO<V4@)&9H.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P
M<&QY*%PD8V]N=&5N="P@(CQE;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.5GM0
M05)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD[
M"E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT
M96YT+"`D9FEL92P@)&YA;64I.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K
M*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@
M07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL
M"G!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2P*)&-O;G1E;G0I.PIO=71S
M*'%Q6U=R:71T96X@87,@(B1N86UE(ETI.PI]"GT*)'II<"T^=W)I=&54;T9I
M;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D
M8V%C:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M
M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@1&EG97-T.CI3
M2$$M/FYE=R@Q*3L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1O=70["B1C='@M
M/F%D9&9I;&4H)&9H*3L*8VQO<V4@)&9H.PHD8V%C:&5?;F%M92`]("1C='@M
M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N
M9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H
M+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F
M:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*"1005)?
M34%'24,I.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]
M"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N
M86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z
M.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@
M24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D
M:64@<7%;9F1O<&5N*"D@9F%I;&5D.B`D(5T["D%R8VAI=F4Z.EII<#HZ<V5T
M0VAU;FM3:7IE*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE
M=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I
M(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R
M96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP
M.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H
M92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q
M=6EE="`]("$D14Y6>U!!4E]$14)51WT["FEF("AD969I;F5D("1%3E9[4$%2
M7U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E
M86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M
M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R
M+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*
M+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#
M;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D
M97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C
M+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@
M*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S
M9613:7IE*"DI('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S
M:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E
M;'-E('L*;W5T<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D
M9&5S=%]N86UE(ETI.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E
M<W1?;F%M92D["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B
M:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA
M;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M
M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=
M(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N
M<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S
M:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@
M0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P
M871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L
M("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM
M:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@
M=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI
M8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I
M<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E
M<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N
M;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97([
M"G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&
M:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*
M<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E
M($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER
M92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V
M>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E
M<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@
M>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I
M;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*
M979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A
M;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T[
M"F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"![
M"FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0
M?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E
M86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@
M5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP
M("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A
M=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A
M;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII
M9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@
M/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I
M('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D
M14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U
M<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D<WES
M>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@
M)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D
M;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N(&UY("1F:"P@
M(CPZ<F%W(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O
M9VYA;64B.B`D(5T["G-E96L@)&9H+"`M,3@L(#(["FUY("1B=68["G)E860@
M)&9H+"`D8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D
M9F@L("TU."P@,CL*<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O
M+V<["B1S=&UP9&ER("X]("(D<WES>U]D96QI;7UC86-H92TD8G5F(CL*?0IE
M;'-E('L*;7D@)&1I9V5S="`](&5V86P*>PIR97%U:7)E($1I9V5S=#HZ4TA!
M.PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;B!M>2`D9F@L
M("(\.G)A=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R
M;V=N86UE(CH@)"%=.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D[
M"B1C='@M/FAE>&1I9V5S=#L*?2!\?"`D;71I;64["B1S=&UP9&ER("X]("(D
M<WES>U]D96QI;7UC86-H92TD9&EG97-T(CL*?0IC;&]S92@D9F@I.PI]"F5L
M<V4@>PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)'-Y<WM?
M9&5L:6U]=&5M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*
M;6MD:7(@)'-T;7!D:7(L(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@
M:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI
M+SL*?0IS=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO
M9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU
M;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN
M86UE+B0D(CL*;W!E;B!M>2`D9F@L("<^.G)A=R<L("1T96UP;F%M92!O<B!D
M:64@<7%;0V%N)W0@=W)I=&4@(B1T96UP;F%M92(Z("0A73L*<')I;G0@)&9H
M("1C;VYT96YT<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE
M(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M
M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*
M?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!2
M3T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD
M<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM0
M05)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI
M(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X
M*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM0
M05)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]
M*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*
M<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921S>7-[7V5X
M97TB*2!["B1P<F]G;F%M92`N/2`D<WES>U]E>&5].PIR971U<FX["GT*?0IF
M;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421S>7-[<&%T:%]S97!]7$4O+"`D
M14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N
M9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D<WES>U]D
M96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P
M<F]G;F%M921S>7-[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D
M96QI;7TD<')O9VYA;64D<WES>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I
M<B1S>7-[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1S
M>7-[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92![
M"B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI
M;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M
M92`]("(N)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E
M9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN
M960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I
M.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D<WES
M>U]D96QI;7U<12DO)'!W9"1S>7-[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.
M04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@
M)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L
M<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-0
M05=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID
M96QE=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0
M($-,14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%2
M7T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1?
M?3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@
M("`@("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6
M>U!!4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,
M7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@
M*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D
M=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR
M971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B
M0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN
M8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@
M;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L
M:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E
M;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N
M<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R
M7V%R9W,I.PID:64@<7%;<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T
M("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y="G5N
M;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D
M,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF
M("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D
M,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID
M:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@``````
M<&5R;'AS:2YC`%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@```!
M&P,[V````!H```"\AO__A`0``."+__\(`0``L(S__T`!```0C?__8`$``+2-
M__^(`0``.(___\0!``#DC___[`$```"2__\H`@``9)+__T@"``#<DO__;`(`
M`+B3__^8`@``T)/__ZP"``#@E?___`(``!26__\0`P``>)?__S@#``!`F?__
M:`,``-"9__^(`P``')K__Z@#``#@FO__W`,``""B__\@!```T*3__U`$``!H
MI?__K`0``/2Z___D!```B+O__P0%``"\O/__0`4``'R____P````$```````
M```!>E(`!'A!`1L,`0`4````&````(2^__\<`0```$()00!"!D$T````,```
M`-"*___0`````$,)00!!F@:;!9P$G0.>`I\!$4%^0@Y02PH.`$+?WMW<V]H&
M00L``!P```!H````:(O__V``````10YP$4%^30X`0@9!````)````(@```"H
MB___I`````!%"4$`G@*?`4,.@`$107Y=#@!!W]X&03@```"P````)(S__X0!
M````0PE!`$&8")D'F@:;!9P$G0.>`I\!$4%^00[``@)8#@!!W][=W-O:V=@&
M020```#L````;(W__ZP`````1`E!`)\!0P[0`1%!?F`.`$'?!D$````X````
M%`$``/"-__\<`@```$,)00!!F0>:!IL%G`2=`YX"GP$107Y!#K`!`GX.`$'?
MWMW<V]K9!D$````<````4`$``-"/__]D`````$<.(!%!?DP.`$(&00```"``
M``!P`0``%)#__W@`````1`E!`)\!1`XP$4%^4@X`0=\&02@```"4`0``:)#_
M_]P`````0PE!`$&=`YX"GP$107Y!#J!!;0X`0M_>W09!$````,`!```8D?__
M&`````````!,````U`$``!R1__\0`@```$4)00`12']!E`R5"Y8*EPF8")D'
MF@:;!9P$G0.>`I\!$4%^00[@(@)V#@!$W][=W-O:V=C7UM74!D$&2````!``
M```D`@``W)+__S0`````````)````#@"``#\DO__9`$```!$"4$`GP%##C`1
M07X"3@X`0=\&00```"P```!@`@``.)3__\@!````1@E!`$&<!)T#G@*?`1%!
M?D$.L`$"9@X`0=_>W=P&01P```"0`@``T)7__Y``````2PY@$4%^30X`1`9!
M````'````+`"``!`EO__3`````!%#B`107Y(#@!"!D$````P````T`(``&R6
M___$`````$,)00!!G`2=`YX"GP$107Y!#H`!3@H.`$'?WMW<!D$+````0```
M``0#``#\EO__0`<```!'"4$`09<)F`B9!YH&FP6<!)T#G@*?`1%!?D<.\(,"
M`[P!#@!"W][=W-O:V=C7!D$````L````2`,``/B=__^P`@```$,)00!!G0.>
M`I\!$4%^00Z``0*C#@!!W][=!D$````P````>`,``'B@__^8`````$4)00">
M`I\!0PYP$4%^4PH.`$4&0=_>00M!#@!!W]X&00``)````*P#```P@O__7`(`
M``!'#I`!$4%^G@*?`0*'"@X`0M_>!D$+`#0```#4`P``M*#__XP5````1`E!
M`$&:!IL%G`2=`YX"GP$107Y!#N`%`UD%#@!!W][=W-O:!D$`'`````P$```(
MMO__E`````!&#B`107Y$#@!7!D$````X````+`0``'RV__\T`0```$0)00!!
MF0>:!IL%G`2=`YX"GP$107Y!#F!U"@X`0=_>W=S;VMD&00L````P````:`0`
M`'2W__^D`0```$4)00!!FP6<!)T#G@*?`1%!?D$.4`):"@X`0=_>W=S;!D$+
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````__________\``````````/__________````````
M```!`````````-\"`````````0````````#J`@````````\`````````3@4`
M```````,`````````'`;````````#0````````#<7````````/7^_V\`````
M(`(````````%`````````&@.````````!@````````#X`@````````H`````
M````;`4````````+`````````!@`````````%0````````````````````,`
M````````(/T!```````"`````````'`%````````%``````````'````````
M`!<``````````!8```````````!P`````-1;`````````P``<```````````
M``````<`````````V!,````````(`````````"@"````````"0`````````8
M`````````!@```````````````````#[__]O``````$```@`````^?__;P``
M```+````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'\"````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````@``````_____P````"Y7P````````E=````
M``````````````#J70```````.-=````````K5\`````````7@```````+5?
M``````````````````"?7P```````*1?``````````````````"^7P``````
M`$=#0SH@*$%L<&EN92`Q,2XR+C%?9VET,C`R,C`R,3DI(#$Q+C(N,2`R,#(R
M,#(Q.0``+G-H<W1R=&%B`"YI;G1E<G``+F=N=2YH87-H`"YD>6YS>6T`+F1Y
M;G-T<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR
M;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+F-T;W)S`"YD=&]R<P`N
M9'EN86UI8P`N9V]T`"YD871A`"YB<W,`+F-O;6UE;G0`````````````````
M````````````````````````````````````````````````````````````
M```````````````+`````0````(```````````(``````````@```````!X`
M```````````````````!````````````````````$P```/;__V\"````````
M`"`"````````(`(```````#8``````````,`````````"```````````````
M`````!T````+`````@````````#X`@```````/@"````````<`L````````$
M````&P````@`````````&``````````E`````P````(`````````:`X`````
M``!H#@```````&P%```````````````````!````````````````````+0``
M``0````"`````````-@3````````V!,````````H`@````````,`````````
M"``````````8`````````#<````$````0@``````````%@`````````6````
M````<`4````````#````$`````@`````````&`````````!!`````0````8`
M````````<!L```````!P&P```````#0````````````````````$````````
M````````````1P````$````&`````````,`;````````P!L````````<00``
M````````````````(````````````````````$T````!````!@````````#<
M7````````-Q<````````+`````````````````````0`````````````````
M``!3`````0````(`````````"%T````````(70```````#P_````````````
M```````(````````````````````6P````$````"`````````$2<````````
M1)P```````#<````````````````````!````````````````````&D````!
M`````@`````````@G0```````""=````````G`0```````````````````0`
M``````````````````!S`````0````,`````````0/L!``````!`^P``````
M`!`````````````````````(````````````````````>@````$````#````
M`````%#[`0``````4/L````````0````````````````````"```````````
M`````````($````&`````P````````!@^P$``````&#[````````P`$`````
M```$``````````@`````````$``````````\````"`````,`````````(/T!
M```````@_0```````.`!```````````````````(``````````@`````````
MB@````$````#``````````#_`0```````/\```````!H````````````````
M``````$````````(`````````(\````!`````P````````````(`````````
M`0``````>`````````````````````@```````````````````"5````"```
M``,`````````>``"``````!X``$``````&`0```````````````````(````
M````````````````F@````$````P````````````````````>``!```````Q
M`````````````````````0`````````!``````````$````#````````````
M`````````````*D``0``````HP````````````````````$`````````````
%````````
